| Title: | English Indices of Deprivation (IoD25) |
| Version: | 1.0.0 |
| Description: | Set of relative measures of deprivation for small areas (Lower-layer Super Output Areas) across England. |
| License: | CC BY 4.0 |
| URL: | https://douglasmunro.github.io/iod25/ |
| BugReports: | https://github.com/douglasmunro/iod25/issues |
| Depends: | R (≥ 3.5) |
| Suggests: | dplyr, knitr, rmarkdown, spelling, tibble |
| VignetteBuilder: | knitr |
| Config/roxygen2/version: | 8.1.0 |
| Encoding: | UTF-8 |
| Language: | en-GB |
| LazyData: | true |
| NeedsCompilation: | no |
| Packaged: | 2026-09-12 18:30:34 UTC; douglas |
| Author: | Douglas Munro |
| Maintainer: | Douglas Munro <douglas@douglasmunro.co.uk> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-22 07:20:02 UTC |
iod25: English Indices of Deprivation (IoD25)
Description
Data package containing the Indices of Deprivation 2025 (IoD25). Iod25 provide a set of relative measures of deprivation for small areas (Lower-layer Super Output Areas) across England.
Author(s)
Maintainer: Douglas Munro douglas@douglasmunro.co.uk (ORCID) [copyright holder]
Authors:
Douglas Munro douglas@douglasmunro.co.uk (ORCID) [copyright holder]
See Also
Useful links:
Domains of deprivation 2025
Description
This dataset contains the Index of Multiple Deprivation 2025 (IMD 2025) and the seven domains at Lower-layer Super Output Area (LSOA) level.
Usage
domains
Format
A tibble with 270,040 rows and 9 variables:
- lsoa_code
Identifiers of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lsoa_name
Names of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lad_code
Identifiers for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- lad_name
Names for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- measure_type
Measure type (index, domain or subdomain)
- measure_name
Measure name
- rank
Measure rank (where 1 is most deprived)
- decile
Measure decile (where 1 is most deprived 10% of LSOAs)
- score
Measure score
Details
The data has been extracted from the All scores, ranks and deciles source file and transformed into into a long ('tidy') format.
Ministry of Housing, Communities & Local Government (MHCLG), Indices of Multiple Deprivation 2025, (2025). Available at: https://open-data.communities.gov.uk/datasets/indices-of-deprivation-2025/ (Accessed: 25 May 2025). Licensed under the Open Government Licence v3.0.
Index of Multiple Deprivation (IMD) 2025
Description
This dataset contains the ranks and deciles for the Index of Multiple Deprivation 2025 (IMD25) at Lower-layer Super Output Area (LSOA) level.
Usage
imd
Format
A tibble with 33,755 rows and 9 variables:
- lsoa_code
Identifiers of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lsoa_name
Names of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lad_code
Identifiers for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- lad_name
Names for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- measure_type
Measure type (index, domain or subdomain)
- measure_name
Measure name
- rank
Measure rank (where 1 is most deprived)
- decile
Measure decile (where 1 is most deprived 10% of LSOAs)
- score
Measure score
Details
The data has been extracted from the All scores, ranks and deciles source file and transformed into into a long ('tidy') format.
Ministry of Housing, Communities & Local Government (MHCLG), Indices of Multiple Deprivation 2025, (2025). Available at: https://open-data.communities.gov.uk/datasets/indices-of-deprivation-2025/ (Accessed: 25 May 2025). Licensed under the Open Government Licence v3.0.
Population denominators 2025
Description
This dataset contains the population denominators used to create the Indices of Deprivation 2025 (IoD25). The populations are derived from the mid-2022 ONS population estimates.
Usage
population
Format
A tibble with 135,020 rows and 6 variables:
- lsoa_code
Identifiers of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lsoa_name
Names of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lad_code
Identifiers for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- lad_name
Names for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- population_group
Population group
- population
Population
Details
The data has been extracted from the All scores, ranks and deciles source file and transformed into into a long ('tidy') format.
Ministry of Housing, Communities & Local Government (MHCLG), Indices of Multiple Deprivation 2025, (2025). Available at: https://open-data.communities.gov.uk/datasets/indices-of-deprivation-2025/ (Accessed: 25 May 2025). Licensed under the Open Government Licence v3.0.
Sub-domains of deprivation 2025
Description
This dataset contains the sub-domains at Lower-layer Super Output Area (LSOA) level.
Usage
subdomains
Format
A tibble with 202,530 rows and 9 variables:
- lsoa_code
Identifiers of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lsoa_name
Names of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lad_code
Identifiers for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- lad_name
Names for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- measure_type
Measure type (index, domain or subdomain)
- measure_name
Measure name
- rank
Measure rank (where 1 is most deprived)
- decile
Measure decile (where 1 is most deprived 10% of LSOAs)
- score
Measure score
Details
The data has been extracted from the All scores, ranks and deciles source file and transformed into into a long ('tidy') format.
Ministry of Housing, Communities & Local Government (MHCLG), Indices of Multiple Deprivation 2025, (2025). Available at: https://open-data.communities.gov.uk/datasets/indices-of-deprivation-2025/ (Accessed: 25 May 2025). Licensed under the Open Government Licence v3.0.
Supplementary indices of deprivation 2025
Description
This dataset contains the supplementary indices of deprivation at Lower-layer Super Output Area (LSOA) level. The supplementary indices are the Income Deprivation Affecting Children Index (IDACI) and the Income Deprivation Affecting Older People Index (IDAOPI).
Usage
supplementary
Format
A tibble with 67,510 rows and 9 variables:
- lsoa_code
Identifiers of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lsoa_name
Names of 2021 Census Geography boundaries (Lower Layer Super Output Areas)
- lad_code
Identifiers for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- lad_name
Names for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024
- measure_type
Measure type (index, domain or subdomain)
- measure_name
Measure name
- rank
Measure rank (where 1 is most deprived)
- decile
Measure decile (where 1 is most deprived 10% of LSOAs)
- score
Measure score
Details
The data has been extracted from the All scores, ranks and deciles source file and transformed into into a long ('tidy') format.
Ministry of Housing, Communities & Local Government (MHCLG), Indices of Multiple Deprivation 2025, (2025). Available at: https://open-data.communities.gov.uk/datasets/indices-of-deprivation-2025/ (Accessed: 25 May 2025). Licensed under the Open Government Licence v3.0.